Module currency

Module currency 

Client-side currency display from inventory stacks.

Functions

apply_coins_delta
Mint or spend physical coin stacks on the client inventory mirror.
copper_from_counts
currency_line
drain_template_stacks
Remove up to qty of a template from root inventory stacks.
format_copper