pub struct WorkerTakePicker {
pub worker_instance_id: String,
pub worker_label: String,
pub options: Vec<WorkerGiveOption>,
pub quantity: u32,
}Expand description
Take an item from a hired worker back into the employer’s inventory.
Fields
worker_instance_id: Stringworker_label: Stringoptions: Vec<WorkerGiveOption>quantity: u32How many of the selected stack to take (1..=stack quantity).